==> MBBEFDLite_0.0.1.tar.gz: MBBEFDLite/README.md <==
---
title: Package MBBEFDLite
---

<!-- badges: start -->
[![](https://www.r-pkg.org/badges/version-last-release/MBBEFDLite)](https://cran.r-project.org/package=MBBEFDLite)
[![](http://cranlogs.r-pkg.org/badges/last-month/MBBEFDLite)](https://cran.r-project.org/package=MBBEFDLite)
[![](https://cranlogs.r-pkg.org/badges/grand-total/MBBEFDLite)](https://cran.r-project.org/package=MBBEFDLite)
[![R-CMD-check](https://github.com/aadler/MBBEFDLite/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/aadler/MBBEFDLite/actions/workflows/R-CMD-check.yaml)
[![Codecov test coverage](https://codecov.io/gh/aadler/MBBEFDLite/branch/master/graph/badge.svg)](https://app.codecov.io/gh/aadler/MBBEFDLite?branch=master)
<!-- badges: end -->

## Description
**MBBEFDLite** is an `R` package which provides the probability mass,
distribution, quantile, random variate generation, and method of moments
parameter estimation functions for the MBBEFD distribution.

## Citation
If you use the package, please cite it as per
[CITATION](https://CRAN.R-project.org/package=MBBEFDLite/citation.html).

## Contributions
Please see
[CONTRIBUTING](https://github.com/aadler/MBBEFDLite/blob/master/CONTRIBUTING.md).

## Security
Please see [SECURITY](https://github.com/aadler/MBBEFDLite/blob/master/SECURITY.md).

## Roadmap
### Major

 * Consider if there is a way to make the method-of-moments fitting more robust
 for cases where the initial `g` is too small---thus `p` is too large.
 
### Minor
 
 * There are no plans for minor changes at current.

==> MBBEFDLite_0.0.2.tar.gz: MBBEFDLite/README.md <==
---
title: Package MBBEFDLite
---

<!-- badges: start -->
[![](https://www.r-pkg.org/badges/version-last-release/MBBEFDLite)](https://cran.r-project.org/package=MBBEFDLite)
[![](http://cranlogs.r-pkg.org/badges/last-month/MBBEFDLite)](https://cran.r-project.org/package=MBBEFDLite)
[![](https://cranlogs.r-pkg.org/badges/grand-total/MBBEFDLite)](https://cran.r-project.org/package=MBBEFDLite)
[![R-CMD-check](https://github.com/aadler/MBBEFDLite/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/aadler/MBBEFDLite/actions/workflows/R-CMD-check.yaml)
[![codecov](https://codecov.io/gh/aadler/MBBEFDLite/branch/master/graph/badge.svg?token=TGV1XMYWRV)](https://app.codecov.io/gh/aadler/MBBEFDLite)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.11204453.svg)](https://doi.org/10.5281/zenodo.11204452)
[![OpenSSF Best Practices](https://www.bestpractices.dev/projects/8950/badge)](https://www.bestpractices.dev/projects/8950)
<!-- badges: end -->

## Description
**MBBEFDLite** is an `R` package which provides the probability mass,
distribution, quantile, random variate generation, and method of moments
parameter estimation functions for the MBBEFD distribution.

## Citation
If you use the package, please cite it as per
[CITATION](https://CRAN.R-project.org/package=MBBEFDLite/citation.html).

## Contributions
Please see
[CONTRIBUTING](https://github.com/aadler/MBBEFDLite/blob/master/CONTRIBUTING.md).

## Security
Please see [SECURITY](https://github.com/aadler/MBBEFDLite/blob/master/SECURITY.md).

## Roadmap
### Major

 * Consider if there is a way to make the method-of-moments fitting more robust
 for cases where the initial `g` is too small---thus `p` is too large.
 
### Minor
 
 * There are no plans for minor changes at current.
